@@ -1,5 +1,3 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
-
 /*
  *  Copyright (C) 2004-2008 Red Hat, Inc.
  *
@@ -14,8 +12,7 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  along with this program; if not, see <https://www.gnu.org/licenses/>.
  *
  *  Authors: Alexander Larsson <alexl@redhat.com>
  *
@@ -256,8 +253,8 @@ get_httpd_config (const char *httpd_program)
 		/* Failed to parse httpd version number */
 		g_warning ("Could not parse '%s' as a version for httpd", standard_output);
 		g_free (standard_output);
-		/* assume it is 2.2 */
-		version_number = g_strdup ("2.2");
+		/* assume it is 2.4 */
+		version_number = g_strdup ("2.4");
 	}
 
 	config = g_strdup_printf (HTTPD_CONFIG_TEMPLATE, version_number);
@@ -282,8 +279,10 @@ spawn_httpd (int port, pid_t *pid_out)
 	GSettings *settings;
 	char *str;
 	char *public_dir;
+	char *httpd_modules_path;
 
 	public_dir = lookup_public_dir ();
+	httpd_modules_path = get_httpd_modules_path ();
 	ensure_conf_dir ();
 
 	i = 0;
@@ -323,7 +322,7 @@ spawn_httpd (int port, pid_t *pid_out)
 	free6 = env[i++] = g_strdup_printf ("XDG_CONFIG_HOME=%s", g_get_user_config_dir ());
 	free7 = env[i++] = g_strdup_printf ("GUS_SHARE_NAME=%s", get_share_name ());
 	free8 = env[i++] = g_strdup_printf ("GUS_LOGIN_LABEL=%s", "Please log in as the user guest");
-	free9 = env[i++] = g_strdup_printf ("HTTP_MODULES_PATH=%s",get_httpd_modules_path ());
+	free9 = env[i++] = g_strdup_printf ("HTTP_MODULES_PATH=%s", httpd_modules_path);
 	env[i++] = "LANG=C";
 	env[i] = NULL;
 
@@ -349,6 +348,7 @@ spawn_httpd (int port, pid_t *pid_out)
 	g_free (free8);
 	g_free (free9);
 	g_free (public_dir);
+	g_free (httpd_modules_path);
 
 	if (!res) {
 		fprintf (stderr, "error spawning httpd: %s\n",
