@@ -1,5 +1,3 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
-
 /*
  *  Copyright (C) 2004-2009 Red Hat, Inc.
  *
@@ -14,8 +12,7 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  along with this program; if not, see <https://www.gnu.org/licenses/>.
  *
  *  Authors: Alexander Larsson <alexl@redhat.com>
  *  Bastien Nocera <hadess@hadess.net>
@@ -54,30 +51,3 @@ lookup_public_dir (void)
 				   "Public",
 				   TRUE);
 }
-
-GFile *
-lookup_dir_with_fallback (GUserDirectory directory)
-{
-	GFile *file;
-	char *path;
-	const char *name;
-
-	if (directory == G_USER_DIRECTORY_PUBLIC_SHARE)
-		name = "Public";
-	else if (directory == G_USER_DIRECTORY_DOWNLOAD)
-		name = "Downloads";
-	else
-		g_assert_not_reached ();
-
-	path = lookup_special_dir (directory,
-				   name,
-				   FALSE);
-
-	if (path == NULL)
-		return NULL;
-
-	file = g_file_new_for_path (path);
-	g_free (path);
-
-	return file;
-}
